summaryrefslogtreecommitdiff
path: root/deps/v8/src/builtins/constants-table-builder.h
diff options
context:
space:
mode:
Diffstat (limited to 'deps/v8/src/builtins/constants-table-builder.h')
-rw-r--r--deps/v8/src/builtins/constants-table-builder.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/deps/v8/src/builtins/constants-table-builder.h b/deps/v8/src/builtins/constants-table-builder.h
index 56547a445e..e8d79202ef 100644
--- a/deps/v8/src/builtins/constants-table-builder.h
+++ b/deps/v8/src/builtins/constants-table-builder.h
@@ -33,10 +33,10 @@ class BuiltinsConstantsTableBuilder final {
uint32_t AddObject(Handle<Object> object);
// Self-references during code generation start out by referencing a handle
// with a temporary dummy object. Once the final Code object exists, such
// entries in the constants map must be patched up.
void PatchSelfReference(Handle<Object> self_reference,
- Handle<Code> code_object);
+ Handle<InstructionStream> code_object);
// References to the array that stores basic block usage counters start out as
// references to a unique oddball. Once the actual array has been allocated,
@@ -33,10 +33,10 @@ class BuiltinsConstantsTableBuilder final {
uint32_t AddObject(Handle<Object> object);
// Self-references during code generation start out by referencing a handle
- // with a temporary dummy object. Once the final Code object exists, such
- // entries in the constants map must be patched up.
+ // with a temporary dummy object. Once the final InstructionStream object
+ // exists, such entries in the constants map must be patched up.
void PatchSelfReference(Handle<Object> self_reference,